@@ -1,3 +1,4 @@
+from __future__ import annotations # Delays annotation evaluation, allowing modern 3.10+ type syntax and forward references in older Python versions 3.8 and 3.9
 import sqlite3
 from rich.table import Table
 from rich.console import Console
@@ -6,16 +7,36 @@ import typer
 from pathlib import Path
 from importlib.metadata import version, PackageNotFoundError
 from requests.exceptions import Timeout
-import sys 
+import sys
+import pendulum
+
+try:
+    import colorama # explicitly added so for the shiv build
+except ImportError:
+    colorama = None  # or handle gracefully
+try:
+    import tzdata # explicitly added so for the shiv build
+except ImportError:
+    tzdata = None  # or handle gracefully
 
 from pipeline.time_manager import TimeManager
 from pipeline.create_sensors_db import get_db_connection, create_packaged_db, reset_user_db # get_user_db_path, ensure_user_db, 
-from pipeline.api.eds import demo_eds_webplot_point_live
+from pipeline.api.eds import demo_eds_webplot_point_live, EdsClient, load_historic_data, EdsLoginException, demo_eds_save_point_export
 from pipeline import environment
 from pipeline.security_and_config import get_eds_api_credentials, get_external_api_credentials, get_eds_db_credentials, get_all_configured_urls, get_configurable_plant_name, init_security, CONFIG_PATH
 from pipeline.termux_setup import setup_termux_shortcut
+from pipeline import helpers
+from pipeline.plotbuffer import PlotBuffer
 #from pipeline.helpers import setup_logging
-### Versioning
+
+# --- TERMUX SETUP HOOK ---
+# This runs on every command (including --version and --help or without sub commands), 
+# but the function's internal logic
+# ensures the shortcut file is only created once in the Termux environment.
+if environment.is_termux():
+    setup_termux_shortcut()
+
+# -- Versioning --
 CLI_APP_NAME = "pipeline"
 PIP_PACKAGE_NAME = "pipeline-eds"
 def print_version(value: bool):
@@ -56,17 +77,11 @@ def main(
     """
     Pipeline CLI – run workspaces built on the pipeline framework.
     """
-    
+
     if ctx.invoked_subcommand is None:
         typer.echo(ctx.get_help())
         raise typer.Exit()
     
-    # --- TERMUX SETUP HOOK ---
-    # This runs on every command, but the function's internal logic
-    # ensures the shortcut file is only created once in the Termux environment.
-    if environment.is_termux():
-        setup_termux_shortcut()
-    
     # 1. Access the list of all command-line arguments
     full_command_list = sys.argv
     
@@ -145,11 +160,6 @@ def trend(
     """
     Show a curve for a sensor over time.
     """
-    #from dateutil import parser
-    import pendulum
-    from pipeline.api.eds import EdsClient, load_historic_data, EdsLoginException
-    from pipeline import helpers
-    from pipeline.plotbuffer import PlotBuffer
 
     #zd = api_credentials.get("zd")
     if plant_name is None:
@@ -179,6 +189,8 @@ def trend(
             )
             # This will now be wrapped in the structured error box.
             raise BadParameter(error_message, param_hint="IDCS...")
+    # Convert all idcs values to uppercase, whether input now or stored in config. This assumes all IDCS value are uppcase all the time at every plant.
+    idcs = [s.upper() for s in idcs]
     # --- END Conditional IDCS Input ---
     
 
@@ -398,6 +410,14 @@ def ping(
         print(f"ping url: {url}")
         call_ping(url)
 
+@app.command()
+def export():
+    """
+    Export a list of all EDS Points.
+    """
+    typer.echo("Coming soon.")
+    #demo_eds_save_point_export()
+
 @app.command()
 def help():
     """
